OfflineRegionDefinition class

Description of region to be downloaded. Identifier will be generated when the download is initiated.

Constructors

OfflineRegionDefinition({required LatLngBounds bounds, required String mapStyleUrl, required double minZoom, required double maxZoom, bool includeIdeographs = false})
const
OfflineRegionDefinition.fromMap(Map<String, dynamic> map)
factory

Properties

bounds → LatLngBounds
final
hashCode → int
The hash code for this object.
no setterinherited
includeIdeographs → bool
final
mapStyleUrl → String
final
maxZoom → double
final
minZoom → double
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toMap() → Map<String, dynamic>
toString() → String
A string representation of this object.
override

Operators

operator ==(Object other) → bool
The equality operator.
inherited