UserHeading class

Type represents a geomagnetic value, measured in microteslas, relative to a device axis in three dimensional space.

Constructors

UserHeading({required double? magneticHeading, required double? trueHeading, required double? headingAccuracy, required double? x, required double? y, required double? z, required DateTime timestamp})
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
headingAccuracy → double?
Represents the maximum deviation of where the magnetic heading may differ from the actual geomagnetic heading in degrees. A negative value indicates an invalid heading.
final
magneticHeading → double?
Represents the direction in degrees, where 0 degrees is magnetic North. The direction is referenced from the top of the device regardless of device orientation as well as the orientation of the user interface.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
timestamp → DateTime
Returns a timestamp for when the magnetic heading was determined.
final
trueHeading → double?
Represents the direction in degrees, where 0 degrees is true North. The direction is referenced from the top of the device regardless of device orientation as well as the orientation of the user interface
final
x → double?
Returns a raw value for the geomagnetism measured in the x-axis.
final
y → double?
Returns a raw value for the geomagnetism measured in the y-axis.
final
z → double?
Returns a raw value for the geomagnetism measured in the z-axis.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited